"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getConfigChecks = void 0;
const brokerClientUrlCheck_1 = require("./brokerClientUrlCheck");
const customAcceptFile_1 = require("./customAcceptFile");
const codeAgentDeprecation_1 = require("./codeAgentDeprecation");
const universalConnectionConfigCheck_1 = require("./universalConnectionConfigCheck");
function getConfigChecks(config) {
    return [
        brokerClientUrlCheck(config),
        universalBrokerConnectionsCheck(config),
        acceptFlagsConfigurationCheck(config),
        codeAgentDeprecationCheck(config),
    ];
}
exports.getConfigChecks = getConfigChecks;
const brokerClientUrlCheck = (config) => {
    const url = config.BROKER_CLIENT_URL;
    return {
        id: 'broker-client-url-validation',
        name: 'Broker Client URL Validation Check',
        enabled: url != undefined && url.length > 0,
        check: async function () {
            return await (0, brokerClientUrlCheck_1.validateBrokerClientUrl)({ id: this.id, name: this.name }, config);
        },
    };
};
const universalBrokerConnectionsCheck = (config) => {
    return {
        id: 'universal-broker-connections-config-validation',
        name: 'Universal Broker Client Connections Configuration Check',
        enabled: config.universalBrokerEnabled,
        check: function () {
            return (0, universalConnectionConfigCheck_1.validateUniversalConnectionsConfig)({ id: this.id, name: this.name }, config);
        },
    };
};
const acceptFlagsConfigurationCheck = (config) => {
    return {
        id: 'accept-flags-config-validation',
        name: 'Accept flags Configuration Check',
        enabled: true,
        check: function () {
            return (0, customAcceptFile_1.validateAcceptFlagsConfig)({ id: this.id, name: this.name }, config);
        },
    };
};
const codeAgentDeprecationCheck = (config) => {
    return {
        id: 'code-agent-deprecation-validation',
        name: 'Code Agent Deprecation Check',
        enabled: !config.DISABLE_CODE_AGENT_PREFLIGHT_CHECK,
        check: function () {
            return (0, codeAgentDeprecation_1.validateCodeAgentDeprecation)({ id: this.id, name: this.name }, config);
        },
    };
};
//# sourceMappingURL=index.js.map